mailr13843 - /branches/gui_testing/gui/wizard.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 22, 2011 - 22:00:
Author: bugman
Date: Fri Jul 22 22:00:15 2011
New Revision: 13843

URL: http://svn.gna.org/viewcvs/relax?rev=13843&view=rev
Log:
The dialog Close() rather than Destroy() method is being used to terminate 
the wizard.

This is necessary for Mac OS X.


Modified:
    branches/gui_testing/gui/wizard.py

Modified: branches/gui_testing/gui/wizard.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/wizard.py?rev=13843&r1=13842&r2=13843&view=diff
==============================================================================
--- branches/gui_testing/gui/wizard.py (original)
+++ branches/gui_testing/gui/wizard.py Fri Jul 22 22:00:15 2011
@@ -1126,8 +1126,8 @@
         # Change the status.
         self._status = False
 
-        # Destroy the window.
-        self.Destroy()
+        # Close the window.
+        self.Close()
 
 
     def _display_page(self, i):
@@ -1239,8 +1239,8 @@
                 # Increment the execution counter.
                 self._exec_count[i] += 1
 
-        # Then destroy the dialog.
-        self.Destroy()
+        # Then close the dialog.
+        self.Close()
 
 
     def _seq_loop(self):
@@ -1388,7 +1388,7 @@
 
         # Modal operation.
         if modal:
-            # Show the wizard (it should be destroyed by the _cancel() or 
_ok() methods).
+            # Show the wizard (it should be closed by the _cancel() or _ok() 
methods).
             self.ShowModal()
 
             # Return the status.




Related Messages


Powered by MHonArc, Updated Fri Jul 22 22:40:02 2011